MethodChannelFlutterBugfender class

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
isMock → bool
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

debug(String value) → Future<void>
override
error(String value) → Future<void>
override
fatal(String value) → Future<void>
override
forceSendOnce() → Future<void>
override
getDeviceUri() → Future<Uri>
override
getSessionUri() → Future<Uri>
override
getUserFeedback({String title = "Feedback", String hint = "Please insert your feedback here and click send", String subjectHint = "Subject…", String messageHint = "Your feedback…", String sendButtonText = "Send", String cancelButtonText = "Close"}) → Future<Uri?>
override
info(String value) → Future<void>
override
init(String appKey, {Uri? apiUri, Uri? baseUri, int? maximumLocalStorageSize, bool printToConsole = true, bool enableUIEventLogging = true, bool enableCrashReporting = true, bool enableAndroidLogcatLogging = true, String? overrideDeviceName, String? version, String? build}) → Future<void>
override
log(String value) → Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeDeviceKey(String key) → Future<void>
override
sendCrash(String title, String stacktrace) → Future<Uri>
override
sendIssue(String title, String text) → Future<Uri>
override
sendIssueMarkdown(String title, String markdown) → Future<Uri>
override
sendLog({int line = 0, String method = "", String file = "", LogLevel level = LogLevel.debug, String tag = "", String text = ""}) → Future<void>
override
sendUserFeedback(String title, String text) → Future<Uri>
override
setDeviceBool(String key, bool value) → Future<void>
override
setDeviceFloat(String key, double value) → Future<void>
override
setDeviceInt(String key, int value) → Future<void>
override
setDeviceString(String key, String value) → Future<void>
override
setForceEnabled(bool enabled) → Future<void>
override
setNetworkLoggingCaptureBodies(bool capture) → Future<void>
override
setNetworkLoggingCaptureErrorResponseBodies(bool capture) → Future<void>
override
setNetworkLoggingEnabled(bool enabled) → Future<void>
override
setNetworkLoggingMaxRequestsPerMinute(int? count) → Future<void>
override
setNetworkLoggingRequestObfuscationHandler(NetworkLoggingRequestObfuscationHandler? handler) → Future<void>
override
setNetworkLoggingResponseObfuscationHandler(NetworkLoggingResponseObfuscationHandler? handler) → Future<void>
override
setNetworkLoggingURLFilter({List<String>? allowlist, List<String>? denylist}) → Future<void>
override
setSDKType(String sdkName, int sdkVersion) → Future<void>
override
toString() → String
A string representation of this object.
inherited
trace(String value) → Future<void>
override
warn(String value) → Future<void>
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited